@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojolicious::Plugin::MountPSGI::Proxy;
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -20,6 +20,12 @@ sub register {
   }
   else { $path = $prefix }
 
+  my $script = $conf->{$prefix};
+  unless (-r $script) {
+    my $abs = $app->home->rel_file($script);
+    $script = $abs if -r $abs;
+  }
+
   # Generate route
   my $route =
     $app->routes->route($path)
